pub fn from_reader_with_options<T: Read>(
source: &mut T,
options: &HashSet<DecodeOption>,
) -> Result<Vec<FitDataRecord>>Expand description
Deserialize a FIT file stored in a source that implements io::Read, with additional decode options
pub fn from_reader_with_options<T: Read>(
source: &mut T,
options: &HashSet<DecodeOption>,
) -> Result<Vec<FitDataRecord>>Deserialize a FIT file stored in a source that implements io::Read, with additional decode options