pub struct FitDataMessage {
pub fields: HashMap<u8, Value>,
pub developer_fields: HashMap<(u8, u8), Value>,
/* private fields */
}Expand description
Stores a vector of raw fields described by the preceding Definition message, a Definition message must come before any Data message. The data here will be transfomed into a FitDataRecord using the information from its defintion message and the MessageInfo struct from the FIT profile
Fields
fields: HashMap<u8, Value>Data field mapping of <(dev_data_idx, field_number), Value>
developer_fields: HashMap<(u8, u8), Value>Mutable Data field mapping of <(dev_data_idx, field_number), Value>
Implementations
Sourceimpl FitDataMessage
impl FitDataMessage
Sourcepub fn global_message_number(&self) -> u16
pub fn global_message_number(&self) -> u16
Global message number defined in the FIT profile, set by definition message
Sourcepub fn time_offset(&self) -> Option<u8>
pub fn time_offset(&self) -> Option<u8>
Time offset used to generate a full timestamp from a reference time
Sourcepub fn fields(&self) -> &HashMap<u8, Value>
pub fn fields(&self) -> &HashMap<u8, Value>
Data field mapping of <(dev_data_idx, field_number), Value>
Sourcepub fn fields_mut(&mut self) -> &mut HashMap<u8, Value>
pub fn fields_mut(&mut self) -> &mut HashMap<u8, Value>
Mutable Data field mapping of <(dev_data_idx, field_number), Value>